@@ -175,8 +175,8 @@ def parse_args(argv):
         help='name of the develop branch')
 
     parser.add_argument(
-        '--tag-prefix',
-        help='prefix to prepend to tags')
+        '--tag-suffix',
+        help='suffix to appepend to tags')
 
     parser.add_argument(
         '--json', action='store_true', default=False,
